from mcpstore import MCPStore
store = MCPStore.setup_store()
# store.for_store().add_service({"name":"mcpstore-wiki","url":"http://mcpstore.wiki/mcp"})
d2= {
  "mcpServers": {
    "howtocook": {
      "command": "npx",
      "args": [
        "-y",
        "howtocook-mcp"
      ]
    }
  }
}
store.for_store().add_service(d2)
tools = store.for_store().list_tools()
print(tools)
print(store.for_store().use_tool(tools[0].name,{"query":'北京'}))