from mcpstore import MCPStore
store = MCPStore.setup_store()
# store.for_store().add_service({"name":"mcpstore-wiki","url":"http://mcpstore.wiki/mcp"})
store.for_store().add_service({"name":"context7","url":"https://mcp.context7.com/mcp"})
tools = store.for_store().list_tools()
print(tools)
print(store.for_store().use_tool(tools[0].name,{"query":'北京'}))